INSTALL.txt

# Installing Quixote

Quixote requires Python 3.5 or later.

If you have a previously installed quixote, we strongly recommend that you remove it before installing a new one. First, find out where your old Quixote installation is:

> python3 -c "import os,quixote;print(os.path.dirname(quixote.__file__))"

and then remove away the reported directory. (If the import fails, then you don't have an existing Quixote installation.)

Now install the new version by running (in the distribution directory),

> python3 setup.py install

and you're done.

# Quick start

In a terminal window, run:

> python3 -m quixote run

In a browser, open http://localhost:8080